<script type="text/javascript">
    /* <![CDATA[ */
        $(document).ready(function(){
        $.post( '{{ url }}',{ object_pk : '{{ object_pk }}', ctype_pk :  '{{ ctype_pk }}', csrfmiddlewaretoken: '{{ csrf_token }}'},'json');
        });
    /* ]]> */
</script>